intelmq.bots.experts.modify package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.experts.modify package

## Submodules

## intelmq.bots.experts.modify.expert module

Modify Expert bot let’s you manipulate all fields with a config file.

`intelmq.bots.experts.modify.expert.` `BOT`

  alias of `intelmq.bots.experts.modify.expert.ModifyExpertBot`

class `intelmq.bots.experts.modify.expert.` `MatchGroupMapping`(match)

  Bases: `object`

  Wrapper for a regexp match object with a dict-like interface. With this, we can access the match groups from within a format replacement field.

class `intelmq.bots.experts.modify.expert.` `ModifyExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `apply_action`(event, action, matches)
  `init`()
  `matches`(identifier, event, condition)
  `process`()

`intelmq.bots.experts.modify.expert.` `is_re_pattern`(value)

  Checks if the given value is a re compiled pattern

## Module contents